# Core Aerodynamics Subsystem

The core aerodynamics subsystem is responsible for calculating the aerodynamic forces (lift and drag) acting on the aircraft.
Aviary can use empirically calculated aerodynamic properties or tabular data from user-provided sources.

```{note}
This section is under further development.
```
